summaryrefslogtreecommitdiffstats
path: root/test/cache.c
diff options
context:
space:
mode:
authorQuincey Koziol <koziol@hdfgroup.org>2010-05-06 14:19:28 (GMT)
committerQuincey Koziol <koziol@hdfgroup.org>2010-05-06 14:19:28 (GMT)
commitb95c7d1879120c542490c031c70b88f6e5fa7eaa (patch)
treea5f2c84b23c43eb342220d811d2b9d4f69fb738b /test/cache.c
parent2c38d7ea30aa8829eb7790f7aa25b16dee93fb8f (diff)
downloadhdf5-b95c7d1879120c542490c031c70b88f6e5fa7eaa.zip
hdf5-b95c7d1879120c542490c031c70b88f6e5fa7eaa.tar.gz
hdf5-b95c7d1879120c542490c031c70b88f6e5fa7eaa.tar.bz2
[svn-r18722] Description:
Bring r18721 from trunk to 1.8 branch: Bring r18720 from metadata journaling merging branch to trunk: Bring changes from metadata journaling branch to 'merging' branch: Rename H5[A]C_mark_pinned_or_protected_entry_dirty() to H5[A]C_mark_entry_dirty() and get rid of H5[A]C_mark_pinned_entry_dirty(). Tested on: FreeBSD/32 6.3 (duty) in debug mode (h5committested on trunk)
Diffstat (limited to 'test/cache.c')
-rw-r--r--test/cache.c83
1 files changed, 16 insertions, 67 deletions
diff --git a/test/cache.c b/test/cache.c
index 0c44a6b..cf565c5 100644
--- a/test/cache.c
+++ b/test/cache.c
@@ -10936,8 +10936,7 @@ check_flush_cache__flush_op_eviction_test(H5F_t * file_ptr)
*
* JRM -- 5/17/06
* Complete reqrite of pinned entry tests to accomodate
* the new H5C_mark_pinned_or_protected_entry_dirty()
* call.
*
*-------------------------------------------------------------------------
*/
@@ -12737,13 +12736,12 @@ check_flush_cache__single_entry(H5F_t * file_ptr)
*
* 2) Marked dirty by unprotect or not.
*
* 3) Marked dirty by call to H5C_mark_pinned_entry_dirty() or not.
*
* 4) Marked dirty by call to H5C_mark_pinned_or_protected_entry_dirty()
* while protected or not.
*
* 5) Marked dirty by call to H5C_mark_pinned_or_protected_entry_dirty()
* while pinned or not.
*
* 6) Entry marked for flush or not.
*
@@ -13301,7 +13299,7 @@ check_flush_cache__single_entry_test(H5F_t * file_ptr,
* JRM -- 5/17/06
* Added the pop_mark_dirty_prot and pop_mark_dirty_pinned
* flags and supporting code to allow us to test the
* H5C_mark_pinned_or_protected_entry_dirty() call. Use the
* call to mark the entry dirty while the entry is protected
* if pop_mark_dirty_prot is TRUE, and to mark the entry
* dirty while it is pinned if pop_mark_dirty_pinned is TRUE.
@@ -13369,8 +13367,7 @@ check_flush_cache__pinned_single_entry_test(H5F_t * file_ptr,
if ( pop_mark_dirty_prot ) {
- mark_pinned_or_protected_entry_dirty(entry_type,
- entry_idx);
+ mark_entry_dirty(entry_type, entry_idx);
}
unprotect_entry(file_ptr, entry_type, entry_idx,
@@ -13378,13 +13375,12 @@ check_flush_cache__pinned_single_entry_test(H5F_t * file_ptr,
if ( mark_dirty ) {
- mark_pinned_entry_dirty(entry_type, entry_idx, FALSE, (size_t)0);
+ mark_entry_dirty(entry_type, entry_idx);
}
if ( pop_mark_dirty_pinned ) {
- mark_pinned_or_protected_entry_dirty(entry_type,
- entry_idx);
+ mark_entry_dirty(entry_type, entry_idx);
}
}
@@ -13663,7 +13659,7 @@ check_get_entry_status(void)
if ( pass ) {
- mark_pinned_entry_dirty(0, 0, FALSE, (size_t)0);
+ mark_entry_dirty(0, 0);
}
@@ -17428,13 +17424,7 @@ check_double_unprotect_err(void)
*
* Purpose: Verify that:
*
- * 1) a call to H5C_mark_pinned_entry_dirty with an upinned
- * entry as the target will generate an error.
- *
- * 2) a call to H5C_mark_pinned_entry_dirty with a protected
- * entry as the target will generate an error.
- *
- * 3) a call to H5C_mark_pinned_or_protected_entry_dirty with
+ * 1) a call to H5C_mark_entry_dirty with
* and unpinned and unprotected entry will generate an
* error.
*
@@ -17443,10 +17433,6 @@ check_double_unprotect_err(void)
* Programmer: John Mainzer
* 5/17/06
*
- * Modifications:
- *
- * None.
- *
*-------------------------------------------------------------------------
*/
@@ -17462,14 +17448,8 @@ check_mark_entry_dirty_errs(void)
pass = TRUE;
- /* allocate a cache, protect an entry, and then attempt to mark it dirty
- * with the H5C_mark_pinned_entry_dirty() call -- This should fail.
- *
- * Then unprotect the entry without pinning it, and try to mark it dirty
- * again -- this should fail too.
- *
- * Try it again using H5C_mark_pinned_or_protected_entry_dirty -- this
- * should fail as well.
+ /* allocate a cache, protect an entry, unprotect the entry without
+ * pinning it, and try to mark it dirty -- this should fail.
*
* Destroy the cache -- should succeed.
*/
@@ -17483,52 +17463,21 @@ check_mark_entry_dirty_errs(void)
protect_entry(file_ptr, 0, 0);
- unprotect_entry(file_ptr, 0, 0, FALSE, H5C__PIN_ENTRY_FLAG);
-
- protect_entry(file_ptr, 0, 0);
+ unprotect_entry(file_ptr, 0, 0, FALSE, H5C__NO_FLAGS_SET);
entry_ptr = &((entries[0])[0]);
}
if ( pass ) {
- result = H5C_mark_pinned_entry_dirty((void *)entry_ptr, FALSE, (size_t)0);
-
- if ( result > 0 ) {
-
- pass = FALSE;
- failure_mssg =
- "attempt dirty a pinned and protected entry succeeded.\n";
-
- } else {
-
- unprotect_entry(file_ptr, 0, 0, FALSE, H5C__UNPIN_ENTRY_FLAG);
- }
- }
-
- if ( pass ) {
-
- result = H5C_mark_pinned_entry_dirty((void *)entry_ptr, FALSE, (size_t)0);
-
-
- if ( result > 0 ) {
-
- pass = FALSE;
- failure_mssg =
- "attempt to dirty a unpinned and unprotected entry succeeded 1.\n";
- }
- }
-
- if ( pass ) {
-
- result = H5C_mark_pinned_or_protected_entry_dirty((void *)entry_ptr);
+ result = H5C_mark_entry_dirty((void *)entry_ptr);
if ( result > 0 ) {
pass = FALSE;
failure_mssg =
- "attempt to dirty a unpinned and unprotected entry succeeded 2.\n";
+ "attempt to dirty a unpinned and unprotected entry succeeded.\n";
}
}
@@ -10936,8 +10936,7 @@ check_flush_cache__flush_op_eviction_test(H5F_t * file_ptr)
* JRM -- 5/17/06
* Complete reqrite of pinned entry tests to accomodate
- * the new H5C_mark_pinned_or_protected_entry_dirty()
- * call.
+ * the new H5C_mark_entry_dirty() call.
*
*-------------------------------------------------------------------------
@@ -12737,13 +12736,12 @@ check_flush_cache__single_entry(H5F_t * file_ptr)
* 2) Marked dirty by unprotect or not.
*
- * 3) Marked dirty by call to H5C_mark_pinned_entry_dirty() or not.
+ * 3) Marked dirty by call to H5C_mark_entry_dirty() or not.
*
@@ -12737,13 +12736,12 @@ check_flush_cache__single_entry(H5F_t * file_ptr)
*
- * 4) Marked dirty by call to H5C_mark_pinned_or_protected_entry_dirty()
- * while protected or not.
+ * 4) Marked dirty by call to H5C_mark_entry_dirty() while protected
+ * or not.
*
@@ -12737,13 +12736,12 @@ check_flush_cache__single_entry(H5F_t * file_ptr)
*
- * 5) Marked dirty by call to H5C_mark_pinned_or_protected_entry_dirty()
- * while pinned or not.
+ * 5) Marked dirty by call to H5C_mark_entry_dirty() while pinned or not.
*
* 6) Entry marked for flush or not.
@@ -13301,7 +13299,7 @@ check_flush_cache__single_entry_test(H5F_t * file_ptr,
* Added the pop_mark_dirty_prot and pop_mark_dirty_pinned
* flags and supporting code to allow us to test the
- * H5C_mark_pinned_or_protected_entry_dirty() call. Use the
+ * H5C_mark_entry_dirty() call. Use the
* call to mark the entry dirty while the entry is protected
* if pop_mark_dirty_prot is TRUE, and to mark the entry